@@ -57,6 +57,7 @@ checkArgs_prevs <- function(allArgs, type){
   # Define parameters
   method        <- allArgs$method
   intermediate  <- allArgs$intermediate
+  ConvolNormalization <- allArgs$ConvolNormalization
 
   # Check name of method
   methodList <- c("BelkinOReilly2009", "median_filter")
@@ -69,5 +70,10 @@ checkArgs_prevs <- function(allArgs, type){
     stop("'intermediate' must be a single logical value.")
   }
 
+  # Check 'ConvolNormalization'
+  if(length(ConvolNormalization) != 1 || !is.logical(ConvolNormalization)){
+    stop("'ConvolNormalization' must be a single logical value.")
+  }
+
   return(invisible())
 }
